<?xml version="1.0" encoding="UTF-8" ?>
<!-- showme.xsl
 | DITA showme javascript support - this is the shell XSL for integrating the code modules
 | DITA tutorial and sample gallery launching support - adds javascript to support links to galleries
 | Suppresses IEHS addition of division headings to DITA task files
-->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://icl.com/saxon"
                xmlns:xt="http://www.jclark.com/xt"
                extension-element-prefixes="saxon xt">

<!-- stylesheet imports -->
<!-- the main dita to xhtml converter -->
<xsl:import href="idit2htm.xsl"/>

<!--expected format for showme links:
href: viewlet-name
navtitle/linktext: show me
format: viewlet
type: showme
-->

<!-- Output XHTML with XML syntax, use UFT-8 encoding="UTF-8", transitional XHTML.
     Prevent indenting to conserve space on output. -->
<!-- <xsl:output method="xml" -->
<xsl:output method="xhtml"
            encoding="UTF-8"
            indent="no"
            doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
            doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
/>

<!--Suppress automatic generation of subheadings for tags like <prereq> and <context> in task topics-->
<!--<xsl:param name="GENERATE-TASK-LABELS" select="'NO'"/>-->

<!--Reorder contents so that the title always comes last in the header file (important for search results to display properly)-->
<xsl:template name="chapterHead">
  <head><xsl:value-of select="$newline"/>
    <!-- initial meta information -->
    <xsl:call-template name="generateCharset"/>   <!-- Set the character set to UTF-8 -->
    <xsl:call-template name="generateDefaultCopyright"/> <!-- Generate a default copyright, if needed -->
    <xsl:call-template name="generateDefaultMeta"/> <!-- Standard meta for security, robots, etc -->
    <xsl:call-template name="getMeta"/>           <!-- Process metadata from topic prolog -->
    <xsl:call-template name="copyright"/>         <!-- Generate copyright, if specified manually -->
    <xsl:call-template name="generateCssLinks"/>  <!-- Generate links to CSS files -->
     <xsl:call-template name="generateAccLinks"/>  <!-- Generate Accessibility links start/prev/next files -->
    <!-- Old location of generateChapterTitle -->
    <xsl:call-template name="gen-user-head" />    <!-- include user's XSL HEAD processing here -->
    <xsl:call-template name="gen-user-scripts" /> <!-- include user's XSL javascripts here -->
    <xsl:call-template name="gen-user-styles" />  <!-- include user's XSL style element and content here -->
    <xsl:call-template name="processHDF"/>        <!-- Add user HDF file, if specified -->
    <xsl:call-template name="generateChapterTitle"/> <!-- Generate the <title> element -->
  </head>
  <xsl:value-of select="$newline"/>
</xsl:template>


<!--overriding relinfo-links to ignore showme links-->
<xsl:template name="relinfo-links">
     <!--other info- - not currently sorting by role, since already mixing any number of types in here-->
     <!--if there are links not covered by any of the other routines - ie, not in a linklist, not a child or descendant, not a concept/task/reference, not ancestor/next/previous, not prerequisite - create a section for them and create the links-->
     <xsl:if test="descendant::*
[contains(@class, ' topic/link ')]
[not(ancestor::*[contains(@class,' topic/linklist ')])]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference'or @type='showme')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]">
          <p>
          <b>
             <xsl:call-template name="getString">
                  <xsl:with-param name="stringName" select="'Related information'"/>
               </xsl:call-template>
          </b><br/>
       <!--once section is created, create the links, using the same rules as above plus a uniqueness check-->
       <xsl:for-each select="descendant::*
          [not(ancestor::*[contains(@class,' topic/linklist ')])]
          [generate-id(.)=generate-id(key('link',concat(ancestor::*[contains(@class, ' topic/related-links ')]/parent::*[contains(@class, ' topic/topic ')]/@id, ' ', @href,@type,@role,@platform,@audience,@importance,@outputclass,@keyref,@scope,@format,@otherrole,@product,@otherprops,@rev,@class,child::*))[1])]
[contains(@class, ' topic/link ')]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference' or @type='showme')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]">
          <xsl:apply-templates select="."/>
       </xsl:for-each>

          </p>
     </xsl:if>
</xsl:template>

<!--overriding shortdesc template to introduce showme link before shortdesc-->
<xsl:template match="*[contains(@class,' topic/shortdesc ')]" mode="outofline">
<p>
  <xsl:for-each select="following-sibling::*[contains(@class,' topic/related-links ')]/descendant::*[contains(@class,' topic/link ')][@format='viewlet'][@type='showme']">
	<h5><a>
		<xsl:attribute name="href">javascript:popup_window( '../swf/<xsl:value-of select="@href"/>_viewlet_swf.html?noframes=true', '<xsl:value-of select="@href"/>', 998, 720);</xsl:attribute>
		<xsl:attribute name="decor">none</xsl:attribute>
		<img src="../images/camera2.gif" border="none" align="middle"></img><font color="blue"><xsl:apply-templates/></font></a></h5>
   </xsl:for-each>
  <xsl:call-template name="commonattributes"/>
  <xsl:apply-templates/>
</p>
</xsl:template>

<!--overriding gen-user-scripts stub to call showme javascript-->
<xsl:template name="gen-user-scripts">
	<xsl:call-template name="showme-script"/>
</xsl:template>


<xsl:template name="showme-script">
<script type="text/javascript">
    function popup_window( url, id, width, height )
    {
      popup = window.open( url, id, 'toolbar=no,scrollbars=no,location=no,statusbar=no,menubar=no,resizable=yes,width=' + width + ',height=' + height + ',left=,top=' );
      popup.focus();
    }
</script>
</xsl:template>

</xsl:stylesheet>
